==> milligram-sass-1.3.0.tgz: package/readme.md <==
<a align="center" href="https://milligram.github.io"><img width="100%" src="https://milligram.github.io/images/thumbnail.png" alt="Milligram - A minimalist CSS framework on Sass version."></a>

> A minimalist CSS framework on Sass version.

[![Travis Status](https://travis-ci.org/milligram/milligram-sass.svg?branch=master)](https://travis-ci.org/milligram/milligram-sass?branch=master)
[![AppVeyor Status](https://ci.appveyor.com/api/projects/status/6k58nb7927suv4e0?svg=true)](https://ci.appveyor.com/project/cjpatoilo/milligram-sass)
[![Codacy Status](https://img.shields.io/codacy/grade/82f7acf539d0457891ca91e16204c6f7/master.svg)](https://www.codacy.com/app/milligram/milligram-sass/dashboard)
[![Dependencies Status](https://david-dm.org/milligram/milligram-sass.svg)](https://travis-ci.org/milligram/milligram-sass?branch=master)
[![Version Status](https://badge.fury.io/js/milligram-sass.svg)](https://www.npmjs.com/package/milligram-sass)
[![Download Status](https://img.shields.io/npm/dt/milligram-sass.svg)](https://www.npmjs.com/package/milligram-sass)
[![Gitter Chat](https://img.shields.io/badge/gitter-join_the_chat-4cc61e.svg)](https://gitter.im/milligram/milligram)


## Why it's awesome

Milligram provides a minimal setup of styles for a fast and clean starting point. Just it! **Only 2kb gzipped!** It's not about a UI framework. Specially designed for better performance and higher productivity with fewer properties to reset resulting in cleaner code. Hope you enjoy!


## Download

**Install with Bower**

```sh
$ bower install milligram-sass
```

**Install with npm**

```sh
$ npm install milligram-sass
```

**Install with Yarn**

```sh
$ yarn add milligram-sass
```


## Table of Contents

- [Getting Started](https://milligram.github.io/#getting-started)
- [Typography](https://milligram.github.io/#typography)
- [Blockquotes](https://milligram.github.io/#blockquotes)
- [Buttons](https://milligram.github.io/#buttons)
- [Lists](https://milligram.github.io/#lists)
- [Forms](https://milligram.github.io/#forms)
- [Tables](https://milligram.github.io/#tables)
- [Grids](https://milligram.github.io/#grids)
- [Codes](https://milligram.github.io/#codes)
- [Utilities](https://milligram.github.io/#utilities)
- [Tips](https://milligram.github.io/#tips)
- [Browser Support](https://milligram.github.io/#browser-support)
- [Examples](https://milligram.github.io/#examples)


## Contributing

Want to contribute? Follow these [recommendations](https://github.com/milligram/milligram-sass/blob/master/.github/contributing.md).


## License

Designed with ♥ by [CJ Patoilo](http://cjpatoilo.com). Licensed under the [MIT License](http://cjpatoilo.mit-license.org).

==> milligram-sass-1.4.0.tgz: package/readme.md <==
<a align="center" href="https://milligram.io"><img width="100%" src="https://milligram.io/images/thumbnail.png" alt="Milligram - A minimalist CSS framework."></a>

> A minimalist CSS framework on Sass version.

[![Travis Status](https://travis-ci.org/milligram/milligram-sass.svg?branch=master)](https://travis-ci.org/milligram/milligram-sass?branch=master)
[![AppVeyor Status](https://ci.appveyor.com/api/projects/status/6k58nb7927suv4e0?svg=true)](https://ci.appveyor.com/project/cjpatoilo/milligram-sass)
[![Codacy Status](https://img.shields.io/codacy/grade/82f7acf539d0457891ca91e16204c6f7/master.svg)](https://www.codacy.com/app/milligram/milligram-sass/dashboard)
[![Dependencies Status](https://david-dm.org/milligram/milligram-sass.svg)](https://travis-ci.org/milligram/milligram-sass?branch=master)
[![Version Status](https://badge.fury.io/js/milligram-sass.svg)](https://www.npmjs.com/package/milligram-sass)
[![Download Status](https://img.shields.io/npm/dt/milligram-sass.svg)](https://www.npmjs.com/package/milligram-sass)
[![Gitter Chat](https://img.shields.io/badge/gitter-join_the_chat-4cc61e.svg)](https://gitter.im/milligram/milligram)

## Why it's awesome

Milligram provides a minimal setup of styles for a fast and clean starting point. Just it! **Only 2kb gzipped!** It's not about a UI framework. Specially designed for better performance and higher productivity with fewer properties to reset resulting in cleaner code. Hope you enjoy!

## Download

**Install with Bower**

```sh
$ bower install milligram-sass
```

**Install with npm**

```sh
$ npm install milligram-sass
```

**Install with Yarn**

```sh
$ yarn add milligram-sass
```

## Table of Contents

- [Getting Started](https://milligram.io/#getting-started)
- [Typography](https://milligram.io/#typography)
- [Blockquotes](https://milligram.io/#blockquotes)
- [Buttons](https://milligram.io/#buttons)
- [Lists](https://milligram.io/#lists)
- [Forms](https://milligram.io/#forms)
- [Tables](https://milligram.io/#tables)
- [Grids](https://milligram.io/#grids)
- [Code](https://milligram.io/#code)
- [Utilities](https://milligram.io/#utilities)
- [Tips](https://milligram.io/#tips)
- [Browser Support](https://milligram.io/#browser-support)
- [Examples](https://milligram.io/#examples)

## Contributing

Want to contribute? Follow these [recommendations](https://github.com/milligram/milligram-sass/contribute).

## License

Designed with ♥ by [CJ Patoilo](https://twitter.com/cjpatoilo). Licensed under the [MIT License](https://cjpatoilo.com/license).
